# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class AppointmentReason(str, enum.Enum):
    CHECKUP = "CHECKUP"
    EMERGENCY = "EMERGENCY"
    FOLLOWUP = "FOLLOWUP"
    ROUTINE = "ROUTINE"
    WALKIN = "WALKIN"

    def visit(
        self,
        checkup: typing.Callable[[], T_Result],
        emergency: typing.Callable[[], T_Result],
        followup: typing.Callable[[], T_Result],
        routine: typing.Callable[[], T_Result],
        walkin: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is AppointmentReason.CHECKUP:
            return checkup()
        if self is AppointmentReason.EMERGENCY:
            return emergency()
        if self is AppointmentReason.FOLLOWUP:
            return followup()
        if self is AppointmentReason.ROUTINE:
            return routine()
        if self is AppointmentReason.WALKIN:
            return walkin()



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class AppointmentType(str, enum.Enum):
    COMPLETE = "Complete"
    NORMAL = "Normal"
    TENTATIVE = "Tentative"

    def visit(
        self,
        complete: typing.Callable[[], T_Result],
        normal: typing.Callable[[], T_Result],
        tentative: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is AppointmentType.COMPLETE:
            return complete()
        if self is AppointmentType.NORMAL:
            return normal()
        if self is AppointmentType.TENTATIVE:
            return tentative()



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic

from ......core.datetime_utils import serialize_datetime
from ......core.pydantic_utilities import deep_union_pydantic_dicts
from .....commons.types.invoice_id import InvoiceId
from .....commons.types.organization_id import OrganizationId
from .....commons.types.patient_external_id import PatientExternalId
from .....financials.types.allocation import Allocation
from .....financials.types.patient_transaction_source import PatientTransactionSource
from .....financials.types.refund_reason import RefundReason
from .patient_refund_id import PatientRefundId


class PatientRefund(pydantic.BaseModel):
    patient_refund_id: PatientRefundId
    organization_id: OrganizationId
    source_internal_id: typing.Optional[str] = None
    refund_source: PatientTransactionSource
    amount_cents: int
    patient_external_id: PatientExternalId
    refund_timestamp: typing.Optional[dt.datetime] = None
    refund_note: typing.Optional[str] = None
    allocations: typing.List[Allocation]
    invoice: typing.Optional[InvoiceId] = None
    refund_reason: typing.Optional[RefundReason] = None

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults_exclude_unset: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        kwargs_with_defaults_exclude_none: typing.Any = {"by_alias": True, "exclude_none": True, **kwargs}

        return deep_union_pydantic_dicts(
            super().dict(**kwargs_with_defaults_exclude_unset), super().dict(**kwargs_with_defaults_exclude_none)
        )

    class Config:
        frozen = True
        smart_union = True
        extra = pydantic.Extra.forbid
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class ThirdPartyPayerSortField(str, enum.Enum):
    NAME = "NAME"
    CATEGORY = "CATEGORY"
    ENABLED = "ENABLED"
    UPDATED_AT = "UPDATED_AT"

    def visit(
        self,
        name: typing.Callable[[], T_Result],
        category: typing.Callable[[], T_Result],
        enabled: typing.Callable[[], T_Result],
        updated_at: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is ThirdPartyPayerSortField.NAME:
            return name()
        if self is ThirdPartyPayerSortField.CATEGORY:
            return category()
        if self is ThirdPartyPayerSortField.ENABLED:
            return enabled()
        if self is ThirdPartyPayerSortField.UPDATED_AT:
            return updated_at()



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class ContactPointUse(str, enum.Enum):
    HOME = "HOME"
    WORK = "WORK"
    TEMP = "TEMP"
    OLD = "OLD"
    MOBILE = "MOBILE"

    def visit(
        self,
        home: typing.Callable[[], T_Result],
        work: typing.Callable[[], T_Result],
        temp: typing.Callable[[], T_Result],
        old: typing.Callable[[], T_Result],
        mobile: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is ContactPointUse.HOME:
            return home()
        if self is ContactPointUse.WORK:
            return work()
        if self is ContactPointUse.TEMP:
            return temp()
        if self is ContactPointUse.OLD:
            return old()
        if self is ContactPointUse.MOBILE:
            return mobile()



# This file was auto-generated by Fern from our API Definition.

from .appointment import Appointment
from .appointment_id import AppointmentId
from .appointment_reason import AppointmentReason
from .appointment_sort_field import AppointmentSortField
from .appointment_type import AppointmentType
from .appointment_work_queue import AppointmentWorkQueue
from .mutable_appointment import MutableAppointment
from .service import Service
from .universal_service_identifier import UniversalServiceIdentifier

__all__ = [
    "Appointment",
    "AppointmentId",
    "AppointmentReason",
    "AppointmentSortField",
    "AppointmentType",
    "AppointmentWorkQueue",
    "MutableAppointment",
    "Service",
    "UniversalServiceIdentifier",
]



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class AppointmentSortField(str, enum.Enum):
    START_TIMESTAMP = "startTimestamp"
    UPDATED_AT = "updatedAt"

    def visit(
        self, start_timestamp: typing.Callable[[], T_Result], updated_at: typing.Callable[[], T_Result]
    ) -> T_Result:
        if self is AppointmentSortField.START_TIMESTAMP:
            return start_timestamp()
        if self is AppointmentSortField.UPDATED_AT:
            return updated_at()



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic

from ........core.datetime_utils import serialize_datetime
from ........core.pydantic_utilities import deep_union_pydantic_dicts
from .....common.types.payer_id import PayerId
from .....common.types.period import Period
from .insurance_type_code import InsuranceTypeCode
from .network_type import NetworkType


class InsurancePlan(pydantic.BaseModel):
    member_id: str
    payer_id: PayerId
    payer_name: str
    group_number: typing.Optional[str] = None
    name: typing.Optional[str] = None
    plan_type: typing.Optional[NetworkType] = None
    type: typing.Optional[InsuranceTypeCode] = None
    period: typing.Optional[Period] = None
    insurance_card_image_locator: typing.Optional[str] = None

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults_exclude_unset: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        kwargs_with_defaults_exclude_none: typing.Any = {"by_alias": True, "exclude_none": True, **kwargs}

        return deep_union_pydantic_dicts(
            super().dict(**kwargs_with_defaults_exclude_unset), super().dict(**kwargs_with_defaults_exclude_none)
        )

    class Config:
        frozen = True
        smart_union = True
        extra = pydantic.Extra.forbid
        json_encoders = {dt.datetime: serialize_datetime}
